@@ -14,7 +14,7 @@ var dirs = [
   '/test/pummel'
 ]
 
-cp.execSync('rm -rf node/*.js', { cwd: path.join(__dirname, '../test') })
+cp.execSync('rm -rf node/test-*.js', { cwd: path.join(__dirname, '../test') })
 
 var httpOpts = {
   headers: {
@@ -38,11 +38,22 @@ function downloadBufferTests (dir, files) {
   files.forEach(function (file) {
     if (!/test-buffer.*/.test(file.name)) return
 
-    if (file.name === 'test-buffer-fakes.js') {
-      // These teses only apply to node, where they're calling into C++ and need to
-      // ensure the prototype can't be faked, or else there will be a segfault.
-      return
-    }
+    const skipFileNames = [
+      // Only applies to node. Calls into C++ and needs to ensure the prototype can't
+      // be faked, or else there will be a segfault.
+      'test-buffer-fakes.js',
+      // Tests SharedArrayBuffer support, which is obscure and now temporarily
+      // disabled in all browsers due to the Spectre/Meltdown security issue.
+      'test-buffer-sharedarraybuffer.js',
+      // References Node.js internals, irrelevant to browser implementation
+      'test-buffer-bindingobj-no-zerofill.js',
+      // Destructive test, modifies buffer.INSPECT_MAX_BYTES and causes later tests
+      // to fail.
+      'test-buffer-inspect.js'
+    ]
+
+    // Skip test files with these names
+    if (skipFileNames.includes(file.name)) return
 
     console.log(file.download_url)
 
@@ -72,7 +83,7 @@ function testfixer (filename) {
     }
 
     // make `require('../common')` work
-    line = line.replace(/require\('\.\.\/common'\);/g, 'require(\'./common\')')
+    line = line.replace(/require\('\.\.\/common'\);/g, 'require(\'./common\');')
 
     // require browser buffer
     line = line.replace(/(.*)require\('buffer'\)(.*)/g, '$1require(\'../../\')$2')
